function [f,ll] = norm_pdf(x,muX,sigmaX)
% [f,ll] = norm_pdf(x, muX , sigmaX )
% return PDF of normal distribution
%    x      - set of values at which the PDF is computed
%    muX    - mean of X
%    sigmaX - standard deviation of X
%
%    Reference: http://en.wikipedia.org/wiki/normal_distribution

  if nargin == 1
    muX    = 0;
    sigmaX = 1;
  else 
    muX    = params(1);		% mean of X
    sigmaX = params(2);		% standard deviation of X
  end

  f = 1/sqrt(2*pi*sigmaX^2) * exp ( -0.5 * ( (x - muX)/sigmaX ).^2 );

% -------------------------------------------------------------------- norm_pdf 
% HP Gavin 2024-02-20
